=== modified file 'bzrlib/smart/request.py'
--- bzrlib/smart/request.py	2007-04-24 10:40:22 +0000
+++ bzrlib/smart/request.py	2007-04-24 10:52:16 +0000
@@ -92,6 +92,14 @@
         return "<SmartServerResponse args=%r body=%r>" % (self.args, self.body)
 
 
+class FailedSmartServerResponse(SmartServerResponse):
+    """A SmartServerResponse for a request which failed."""
+
+    def is_successful(self):
+        """FailedSmartServerResponse are not successful."""
+        return False
+
+
 class SuccessfulSmartServerResponse(SmartServerResponse):
     """A SmartServerResponse for a successfully completed request."""
 

=== modified file 'bzrlib/tests/test_smart_transport.py'
--- bzrlib/tests/test_smart_transport.py	2007-04-24 10:40:22 +0000
+++ bzrlib/tests/test_smart_transport.py	2007-04-24 10:52:16 +0000
@@ -1926,6 +1926,21 @@
         self.assertEqual(True, response.is_successful())
 
 
+class TestFailedSmartServerResponse(tests.TestCase):
+
+    def test_construct(self):
+        response = request.FailedSmartServerResponse(('foo', 'bar'))
+        self.assertEqual(('foo', 'bar'), response.args)
+        self.assertEqual(None, response.body)
+        response = request.FailedSmartServerResponse(('foo', 'bar'), 'bytes')
+        self.assertEqual(('foo', 'bar'), response.args)
+        self.assertEqual('bytes', response.body)
+
+    def test_is_successful(self):
+        """is_successful should return False for FailedSmartServerResponse."""
+        response = request.FailedSmartServerResponse(('error',))
+        self.assertEqual(False, response.is_successful())
+
 
 class FakeHTTPMedium(object):
     def __init__(self):

